@@ -509,7 +509,7 @@ class ANN():
             
                 #terminate train if the last layer's gradients equal to 0
                 if len(self.w_layers) in gradient_zero_layer_indexes:  
-                    print(f"Session Terminated: layer{gradient_zero_layer_indexes}'s gradient equals to 0, step: {str(i+1)} error: {str(round(error, error_round))}                                      ")
+                    print(f"Session Terminated: layer{gradient_zero_layer_indexes}'s gradients equal to 0, step: {str(i+1)} error: {str(round(error, error_round))}                                      ")
                     return
                 else:
                     print(f"Warning: layer{gradient_zero_layer_indexes}'s gradient equals to 0, step: {str(i+1)} error: {str(round(error, error_round))}                                      ")
@@ -709,13 +709,9 @@ class ANN():
     
     #util: export
     
-    def export(self, directory, file_name= None, include = "essential"):
+    def export(self, directory= r".\\", file_name= None, include= "essential"):
 
         compat_include_params = {"all", "essential", "error_log", "gradients", "fan_io"}
-        
-        #check validity for 'file_name' param 
-        if not file_name.endswith(".json"):
-            raise Exception("'file_name' must end with '.json'")
 
         #check validity for 'include' param
         if type(include) == str:
@@ -733,6 +729,10 @@ class ANN():
         if file_name == None:
             file_name = "model_" + str(time.localtime().tm_mon) + str(time.localtime().tm_mday) + "-" + str(time.localtime().tm_hour) + str(time.localtime().tm_min) + ".json"
 
+        #check validity for 'file_name' param 
+        if not file_name.endswith(".json"):
+            raise Exception("'file_name' must end with '.json'")
+
         model_json = {}
 
         #essential export
@@ -810,7 +810,7 @@ class ANN():
         with open(directory + "\\" + file_name, "w") as f:
             json.dump(model_json, f)
         
-        print("model export successful: " + directory + "\\" + file_name)
+        print(f"model export successful: '{directory}\{file_name}'")
         
         return
 
